MessageGroupStatus class

Represents the grouping status of a message within a sequence of messages from the same author sent close together in time.

Constructors

MessageGroupStatus({required bool isFirst, required bool isLast, required bool isMiddle})
Creates a MessageGroupStatus instance.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
isFirst → bool
True if this is the first message in the group.
final
isLast → bool
True if this is the last message in the group.
final
isMiddle → bool
True if this is a message in the middle of the group (neither first nor last).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited