ChatTypography class abstract

Defines the typography styles used in the chat UI.

Annotations
  • @Freezed.new(fromJson: false, toJson: false)

Constructors

ChatTypography({required TextStyle bodyLarge, required TextStyle bodyMedium, required TextStyle bodySmall, required TextStyle labelLarge, required TextStyle labelMedium, required TextStyle labelSmall})
Creates a ChatTypography instance.
const
factory
ChatTypography.fromThemeData(ThemeData themeData)
Creates ChatTypography from a Material ThemeData.
factory
ChatTypography.standard({String? fontFamily})
Creates a standard set of text styles. Optionally specify a custom fontFamily.
factory

Properties

bodyLarge → TextStyle
Style for large body text (e.g., potentially message content).
no setterinherited
bodyMedium → TextStyle
Style for medium body text (e.g., default message content).
no setterinherited
bodySmall → TextStyle
Style for small body text (e.g., file sizes).
no setterinherited
copyWith → $ChatTypographyCopyWith<ChatTypography>
Create a copy of ChatTypography with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
labelLarge → TextStyle
Style for large labels (e.g., potentially user names).
no setterinherited
labelMedium → TextStyle
Style for medium labels.
no setterinherited
labelSmall → TextStyle
Style for small labels (e.g., timestamps, status).
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

merge(ChatTypography? other) → ChatTypography
Merges this typography scheme with another ChatTypography.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited