ChatImageMessage class

Inheritance

Constructors

ChatImageMessage({Key? key, required ImageMessage message, required int index, ImageProvider<Object>? customImageProvider, Map<String, String>? headers, BorderRadiusGeometry? borderRadius, BoxConstraints? constraints = const BoxConstraints(maxHeight: 300), Widget? overlay, Color? placeholderColor, Color? loadingOverlayColor, Color? loadingIndicatorColor, Color? uploadOverlayColor, Color? uploadIndicatorColor, TextStyle? timeStyle, Color? timeBackground, bool showTime = true, bool showStatus = true, TimeAndStatusPosition timeAndStatusPosition = TimeAndStatusPosition.end, Decoration? decoration})
Creates a widget to display an image message.
const

Properties

borderRadius → BorderRadiusGeometry?
final
constraints → BoxConstraints?
final
customImageProvider → ImageProvider<Object>?
final
decoration → Decoration?
final
hashCode → int
The hash code for this object.
no setterinherited
headers → Map<String, String>?
final
index → int
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
loadingIndicatorColor → Color?
final
loadingOverlayColor → Color?
final
message → ImageMessage
final
overlay → Widget?
final
placeholderColor → Color?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showStatus → bool
final
showTime → bool
final
timeAndStatusPosition → TimeAndStatusPosition
final
timeBackground → Color?
final
timeStyle → TextStyle?
final
uploadIndicatorColor → Color?
final
uploadOverlayColor → Color?
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _ChatImageMessageState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited