LoadMoreNotifier class

A ChangeNotifier used to track the height and loading state of the "Load More" indicator widget.

Inheritance

Constructors

LoadMoreNotifier()

Properties

hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
height → double
The current measured height of the LoadMore widget.
no setter
isLoading → bool
Whether the LoadMore widget is currently indicating a loading state.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → void
Discards any resources used by the object.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
setHeight(double newHeight) → void
Sets the height of the LoadMore widget and notifies listeners if it changes.
setLoading(bool loading) → void
Sets the loading state and notifies listeners if it changes.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited